bungibindies/bun/sqlite
Bun:sqlite module
Types
Functions
pub fn new(to: String) -> Database
pub fn prepare(db: Database, query: String) -> Statement
bun:sqlite.Statement -> prepare()
- Sqlite
Use the db.prepare() method on your Database instance to prepare a SQL query. The result is a Statement instance that will NOT be cached on the Database instance. _The query will not be executed.
Note — Use the
.query()method to prepare a query with caching it on theDatabaseinstance.
pub fn query(db: Database, query: String) -> Statement
bun:sqlite.Database -> query()
- Sqlite
Use the db.query() method on your Database instance to prepare a SQL query. The result is a Statement instance that will be cached on the Database instance. _The query will not be executed.
Note — Use the
.prepare()method to prepare a query without caching it on theDatabaseinstance.