bungibindies/bun/sqlite/param_array

Types

An implementation of javascript’s Array type, but unlike the gleam/javascript/array module, this one allows for the use of Any as a type parameter. This also means Gleam should not be touching this type, let Bun handle that.

pub type ParamArray =
  array.Array(dynamic.Dynamic)

Values

pub fn list_to_paramarray(
  li: List(a),
) -> array.Array(dynamic.Dynamic)

Create a param array from a List.

pub fn new() -> array.Array(dynamic.Dynamic)

Create a new ParamArray instance.

pub fn push(
  array: array.Array(dynamic.Dynamic),
  value: a,
) -> array.Array(dynamic.Dynamic)

Add a value to the end of the array.

Search Document